aboutsummaryrefslogtreecommitdiffstats
path: root/core/tx_pool.go
diff options
context:
space:
mode:
authorPéter Szilágyi <peterke@gmail.com>2018-05-18 16:45:52 +0800
committerPéter Szilágyi <peterke@gmail.com>2018-05-18 17:08:24 +0800
commit49719e21bcd740c5890334f8c0ec8ac3777fb4c6 (patch)
tree81caf3f5e52d25597f16a21b61b4d91ee4e023b0 /core/tx_pool.go
parenta2e43d28d01ef9642c7f6992b78b86bd0696c847 (diff)
downloadgo-tangerine-49719e21bcd740c5890334f8c0ec8ac3777fb4c6.tar
go-tangerine-49719e21bcd740c5890334f8c0ec8ac3777fb4c6.tar.gz
go-tangerine-49719e21bcd740c5890334f8c0ec8ac3777fb4c6.tar.bz2
go-tangerine-49719e21bcd740c5890334f8c0ec8ac3777fb4c6.tar.lz
go-tangerine-49719e21bcd740c5890334f8c0ec8ac3777fb4c6.tar.xz
go-tangerine-49719e21bcd740c5890334f8c0ec8ac3777fb4c6.tar.zst
go-tangerine-49719e21bcd740c5890334f8c0ec8ac3777fb4c6.zip
core, eth: minor txpool event cleanups
Diffstat (limited to 'core/tx_pool.go')
-rw-r--r--core/tx_pool.go28
1 files changed, 14 insertions, 14 deletions
diff --git a/core/tx_pool.go b/core/tx_pool.go
index f23828cb4..f89e11441 100644
--- a/core/tx_pool.go
+++ b/core/tx_pool.go
@@ -444,9 +444,9 @@ func (pool *TxPool) Stop() {
log.Info("Transaction pool stopped")
}
// SubscribeTxPreEvent registers a subscription of TxsPreEvent and
// starts sending event to the given channel.
-func (pool *TxPool) SubscribeTxPreEvent(ch chan<- TxsPreEvent) event.Subscription {
+func (pool *TxPool) SubscribeNewTxsEvent(ch chan<- NewTxsEvent) event.Subscription {
return pool.scope.Track(pool.txFeed.Subscribe(ch))
}
@@ -653,7 +653,7 @@ func (pool *TxPool) add(tx *types.Transaction, local bool) (bool, error) {
log.Trace("Pooled new executable transaction", "hash", hash, "from", from, "to", tx.To())
// We've directly injected a replacement transaction, notify subsystems
- go pool.txFeed.Send(TxsPreEvent{types.Transactions{tx}})
+ go pool.txFeed.Send(NewTxsEvent{types.Transactions{tx}})
return old != nil, nil
}
@@ -712,7 +712,8 @@ func (pool *TxPool) journalTx(from common.Address, tx *types.Transaction) {
}
}
-// promoteTx adds a transaction to the pending (processable) list of transactions.
+// promoteTx adds a transaction to the pending (processable) list of transactions
+// and returns whether it was inserted or an older was better.
//
// Note, this method assumes the pool lock is held!
func (pool *TxPool) promoteTx(addr common.Address, hash common.Hash, tx *types.Transaction) bool {
@@ -746,6 +747,7 @@ func (pool *TxPool) promoteTx(addr common.Address, hash common.Hash, tx *types.T
// Set the potentially new pending nonce and notify any subsystems of the new tx
pool.beats[addr] = time.Now()
pool.pendingState.SetNonce(addr, tx.Nonce()+1)
+
return true
}
@@ -906,7 +908,9 @@ func (pool *TxPool) removeTx(hash common.Hash, outofbound bool) {
// future queue to the set of pending transactions. During this process, all
// invalidated transactions (low nonce, low balance) are deleted.
func (pool *TxPool) promoteExecutables(accounts []common.Address) {
- var promotedTxs types.Transactions
+ // Track the promoted transactions to broadcast them at once
+ var promoted []*types.Transaction
+
// Gather all the accounts potentially needing updates
if accounts == nil {
accounts = make([]common.Address, 0, len(pool.queue))
@@ -937,16 +941,13 @@ func (pool *TxPool) promoteExecutables(accounts []common.Address) {
queuedNofundsCounter.Inc(1)
}
// Gather all executable transactions and promote them
- txs := list.Ready(pool.pendingState.GetNonce(addr))
- for _, tx := range txs {
+ for _, tx := range list.Ready(pool.pendingState.GetNonce(addr)) {
hash := tx.Hash()
- inserted := pool.promoteTx(addr, hash, tx)
- if inserted {
+ if pool.promoteTx(addr, hash, tx) {
log.Trace("Promoting queued transaction", "hash", hash)
- promotedTxs = append(promotedTxs, tx)
+ promoted = append(promoted, tx)
}
}
-
// Drop all transactions over the allowed limit
if !pool.locals.contains(addr) {
for _, tx := range list.Cap(int(pool.config.AccountQueue)) {
@@ -963,10 +964,9 @@ func (pool *TxPool) promoteExecutables(accounts []common.Address) {
}
}
// Notify subsystem for new promoted transactions.
- if promotedTxs.Len() > 0 {
- pool.txFeed.Send(TxsPreEvent{promotedTxs})
+ if len(promoted) > 0 {
+ pool.txFeed.Send(NewTxsEvent{promoted})
}
-
// If the pending limit is overflown, start equalizing allowances
pending := uint64(0)
for _, list := range pool.pending {
@@ -444,9 +444,9 @@ func (pool *TxPool) Stop() {
log.Info("Transaction pool stopped")
}
-// SubscribeTxPreEvent registers a subscription of TxsPreEvent and
+// SubscribeNewTxsEvent registers a subscription of NewTxsEvent and
// starts sending event to the given channel.